@@ -12,6 +12,8 @@ def env_vars():
         "username": os.getenv("TSS_USERNAME"),
         "password": os.getenv("TSS_PASSWORD"),
         "tenant": os.getenv("TSS_TENANT"),
+        "secret_id": os.getenv("SECRET_ID"),
+        "secret_path": os.getenv("SECRET_PATH")
     }
 
 
